Module: Unit4::Checkout
- Defined in:
- lib/unit4/checkout.rb,
lib/unit4/checkout/version.rb
Overview
the main module for the gem, no code really needed here with the current structure
Constant Summary collapse
- VERSION =
"0.2.2"
the main module for the gem, no code really needed here with the current structure
"0.2.2"